AbsoluteAppBarBehavior class

Inheritance

Constructors

AbsoluteAppBarBehavior({bool bouncing = false})
const

Properties

alignCurve → Curve
The curve of the appbar alignment animation.
finalinherited
alignDuration → Duration
The duration of the appbar alignment animation.
finalinherited
bouncing → bool
Whether the appbar will be synchronized when bouncing overscroll occurs.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

align(AppBarPosition appBar, NestedScrollPosition scroll) → AppBarAlignmentCommand?
Determines the alignment of the appbar based on appbar position and scroll.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBouncing(double available, AppBarPosition appBar, NestedScrollPosition scroll) → double
Updates the appbar during bouncing (overscroll) situations Returns any remaining scroll offset that was not consumed.
inherited
setPixels(double available, AppBarPosition appBar, NestedScrollPosition scroll) → double
Updates the given appbar based on available scroll offset, the current appbar position, and the nested scroll position.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited